@@ -9,7 +9,6 @@
 # @Description  : 
 
 from io import BytesIO
-from meutils.pipe import *
 
 from starlette.status import *
 from starlette.responses import *
@@ -18,6 +17,9 @@ from starlette.staticfiles import StaticFiles
 from fastapi import FastAPI, Form, Depends, File, UploadFile, Body, Request
 from multipart.multipart import parse_options_header
 
+# ME
+from meutils.pipe import *
+
 
 # app_ = FastAPI(title='AppZoo')  # todo: 全局变量
 
@@ -37,13 +39,11 @@ class App(object):
         self.app = FastAPI(title='AppZoo')
         # self.app = app_
 
-        self.verbose = verbose  # 是否返回请求体 # todo删除
-
         # 原生接口
         self.get = self.app.get
         self.post = self.app.post
         self.api_route = self.app.api_route
-        self.mount = self.app.mount
+        self.mount = self.app.mount  # mount('/subapi', subapp)
 
     def run(self, app=None, host="0.0.0.0", port=8000, workers=1, access_log=True, debug=False, **kwargs):
         """
@@ -79,7 +79,24 @@ class App(object):
         handler = self._handler(func, method, **kwargs)
         self.app.api_route(path=path, methods=[method])(handler)
 
-    def add_route_plus(self, path='/xxx', func=lambda x='demo': x, method="GET", **kwargs):
+    def add_route_plus(self, path='/xxx', func=None, method="GET", **kwargs):
+        """
+
+        :param path:
+        :param func:
+            @lru_cache()
+            def cache(kwargs: str):
+                time.sleep(3)
+                return kwargs # json.load(kwargs.replace("'", '"'))
+
+            def nocache(kwargs: dict): # 不指定类型默认字典输入
+                time.sleep(3)
+                return kwargs
+        :param method:
+        :param kwargs:
+        :return:
+        """
+        assert isinstance(func, Callable)
 
         handler = self._handler_plus(func, **kwargs)
 
@@ -176,36 +193,31 @@ class App(object):
 
         return handler
 
-    def _handler_plus(self, func, result_key='data', **kwargs):
-        """
-
-        :param func:
-        :param result_key:
-        :return:
-        """
+    def _handler_plus(self, func, **kwargs):
 
         # todo: 兼容其他请求，比如 request.form()
         async def handler(request: Request):
             # content_type_header = request.headers.get("Content-Type")
             # content_type, options = parse_options_header(content_type_header)
 
-            query_input = request.query_params._dict
-            json_input = await request.json()
+            input = request.query_params._dict
+            body = await request.body()  # get 一般为空
 
-            duplicate_key = query_input.keys() & json_input.keys()
-            if duplicate_key:
-                logger.warning(f"Duplicate key:{duplicate_key}")
+            if body:
+                input.update(json.loads(body))  # 避免重复 key
 
-            input = {**query_input, **json_input}
+            # input4str 方便 cache
+            if str(func.__annotations__).__contains__('str'):
+                input = str(input)
 
-            return self._try_func(input, func, result_key, **kwargs)
+            return self._try_func_plus(input, func, **kwargs)
 
         return handler
 
-    def _try_func(self, kwargs, func, result_key='data', **kwargs_):
-        __debug = 1 if kwargs.pop('__debug', 0) else 0
+    @staticmethod
+    def _try_func(input, func, result_key='data', **kwargs):  # todo: 可否用装饰器
+        __debug = input.pop('__debug', 0)
 
-        input = kwargs
         output = OrderedDict()
         output['error_code'] = 0
         output['error_msg'] = "SUCCESS"
@@ -222,7 +234,26 @@ class App(object):
             output['error_msg'] = traceback.format_exc().strip() if __debug else error  # debug状态获取详细信息
 
         finally:
-            output.update(kwargs_)
+            output.update(kwargs)
+
+        return output
+
+    @staticmethod
+    def _try_func_plus(input, func, result_key='data', **kwargs):
+
+        output = OrderedDict()
+        output['error_code'] = 0
+        output['error_msg'] = "SUCCESS"
+
+        try:
+            output[result_key] = func(input)
+
+        except Exception as error:
+            output['error_code'] = 1  # 通用错误
+            output['error_msg'] = traceback.format_exc().strip()  # debug状态获取详细信息
+
+        finally:
+            output.update(kwargs)
 
         return output
 
