@@ -23,7 +23,19 @@ app.add_route_plus('/post_test', lambda **kwargs: kwargs, method="POST")
 
 def read_func(**kwargs):
     logger.info(kwargs)
-    return pd.read_csv(kwargs['files'][0], names=['word']).to_dict('r')
+    logger.info(pd.read_csv(kwargs['files'][0], names=['word']).to_dict('r'))
+    return
+
+
+from fastapi import FastAPI, Form, Depends, File, UploadFile, Body, Request, Path
+
+
+def f(**kwargs):
+    logger.info(kwargs)
+
+app.add_route('/p/{a}', f, method="GET", result_key="GetResult")
+
+
 
 app.add_route_uploadfiles('/upload', read_func)
 
